@@ -22,7 +22,7 @@ from ..core.config import BaseConfig, AlertConfig, ZoneConfig
 
 @dataclass
 class ConcreteCrackConfig(BaseConfig):
-    """Configuration for concrete crack detection use case in concrete crack monitoring."""
+    """Configuration for Concrete Crack detection use case."""
     # Smoothing configuration
     enable_smoothing: bool = True
     smoothing_algorithm: str = "observability"  # "window" or "observability"
@@ -34,11 +34,11 @@ class ConcreteCrackConfig(BaseConfig):
     confidence_threshold: float = 0.6
 
     usecase_categories: List[str] = field(
-        default_factory=lambda: ['Cracks']
+        default_factory=lambda:  ["Cracks"]
     )
 
     target_categories: List[str] = field(
-        default_factory=lambda: ['Cracks']
+        default_factory=lambda: ["Cracks"]
     )
 
     alert_config: Optional[AlertConfig] = None
@@ -55,22 +55,23 @@ class ConcreteCrackUseCase(BaseProcessor):
     CATEGORY_DISPLAY = {
         "Cracks": "Cracks",
     }
+
+
     def __init__(self):
         super().__init__("concrete_crack_detection")
         self.category = "general"
 
         self.CASE_TYPE: Optional[str] = 'concrete_crack_detection'
-        self.CASE_VERSION: Optional[str] = '1.3'
-
+        self.CASE_VERSION: Optional[str] = '1.2'
         # List of  categories to track
-        self.target_categories = ["Cracks"]
+        self.target_categories =  ["Cracks"]
+
 
         # Initialize smoothing tracker
         self.smoothing_tracker = None
 
         # Initialize advanced tracker (will be created on first use)
         self.tracker = None
-
         # Initialize tracking state variables
         self._total_frame_counter = 0
         self._global_frame_offset = 0
@@ -87,6 +88,7 @@ class ConcreteCrackUseCase(BaseProcessor):
         self._ascending_alert_list: List[int] = []
         self.current_incident_end_timestamp: str = "N/A"
 
+
     def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None,
                 stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
         """
@@ -145,9 +147,25 @@ class ConcreteCrackUseCase(BaseProcessor):
 
             # Create tracker instance if it doesn't exist (preserves state across frames)
             if self.tracker is None:
-                tracker_config = TrackerConfig()
+                # Configure tracker thresholds based on the use-case confidence threshold so that
+                # low-confidence detections (e.g. < 0.7) can still be initialised as tracks when
+                # the user passes a lower `confidence_threshold` in the post-processing config.
+                if config.confidence_threshold is not None:
+                    tracker_config = TrackerConfig(
+                        track_high_thresh=float(config.confidence_threshold),
+                        # Allow even lower detections to participate in secondary association
+                        track_low_thresh=max(0.05, float(config.confidence_threshold) / 2),
+                        new_track_thresh=float(config.confidence_threshold)
+                    )
+                else:
+                    tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
-                self.logger.info("Initialized AdvancedTracker for  Monitoring and tracking")
+                self.logger.info(
+                    "Initialized AdvancedTracker for Monitoring and tracking with thresholds: "
+                    f"high={tracker_config.track_high_thresh}, "
+                    f"low={tracker_config.track_low_thresh}, "
+                    f"new={tracker_config.new_track_thresh}"
+                )
 
             # The tracker expects the data in the same format as input
             # It will add track_id and frame_id to each detection
@@ -186,8 +204,7 @@ class ConcreteCrackUseCase(BaseProcessor):
         # Step: Generate structured incidents, tracking stats and business analytics with frame-based keys
         incidents_list = self._generate_incidents(counting_summary, alerts, config, frame_number, stream_info)
         tracking_stats_list = self._generate_tracking_stats(counting_summary, alerts, config, frame_number, stream_info)
-        # business_analytics_list = self._generate_business_analytics(counting_summary, alerts, config, frame_number, stream_info, is_empty=True)
-        business_analytics_list = []
+        business_analytics_list = self._generate_business_analytics(counting_summary, alerts, config, stream_info, is_empty=True)
         summary_list = self._generate_summary(counting_summary, incidents_list, tracking_stats_list, business_analytics_list, alerts)
 
         # Extract frame-based dictionaries from the lists
@@ -202,7 +219,8 @@ class ConcreteCrackUseCase(BaseProcessor):
                         "alerts": alerts,
                         "human_text": summary}
                     }
-    
+       
+       
         context.mark_completed()
 
         # Build result object following the new pattern
@@ -264,8 +282,8 @@ class ConcreteCrackUseCase(BaseProcessor):
                         "threshold_level": threshold,
                         "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
                         "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
-                                    getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
-                                }                    
+                                     getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
+                                    }                    
                     })
                 elif category in summary.get("per_category_count", {}):
                     count = summary.get("per_category_count", {})[category]
@@ -277,15 +295,15 @@ class ConcreteCrackUseCase(BaseProcessor):
                             "threshold_level": threshold,
                             "ascending": get_trend(self._ascending_alert_list, lookback=900, threshold=0.8),
                             "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
-                                    getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
-                                }       
+                                     getattr(config.alert_config, 'alert_value', ['JSON']) if hasattr(config.alert_config, 'alert_value') else ['JSON'])
+                                    }       
                         })
         else:
             pass
         return alerts
 
     def _generate_incidents(self, counting_summary: Dict, alerts: List, config: ConcreteCrackConfig,
-                        frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[
+                         frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[
         Dict]:
         """Generate structured incidents for the output format with frame-based keys."""
         
@@ -343,7 +361,7 @@ class ConcreteCrackUseCase(BaseProcessor):
                     intensity = min(10.0, total_detections / 3.0)
                     self._ascending_alert_list.append(0)
 
-            # Generate human text in new format
+             # Generate human text in new format
             human_text_lines = [f"INCIDENTS DETECTED @ {current_timestamp}:"]
             human_text_lines.append(f"\tSeverity Level: {(self.CASE_TYPE,level)}")
             human_text = "\n".join(human_text_lines)
@@ -361,9 +379,9 @@ class ConcreteCrackUseCase(BaseProcessor):
                 })
         
             event= self.create_incident(incident_id=self.CASE_TYPE+'_'+str(frame_number), incident_type=self.CASE_TYPE,
-                    severity_level=level, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
-                    start_time=start_timestamp, end_time=self.current_incident_end_timestamp,
-                    level_settings= {"low": 1, "medium": 3, "significant":4, "critical": 7})
+                       severity_level=level, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
+                       start_time=start_timestamp, end_time=self.current_incident_end_timestamp,
+                       level_settings= {"low": 1, "medium": 3, "significant":4, "critical": 7})
             incidents.append(event)
 
         else:
@@ -371,7 +389,6 @@ class ConcreteCrackUseCase(BaseProcessor):
             incidents.append({})
            
         return incidents
-
     def _generate_tracking_stats(
             self,
             counting_summary: Dict,
@@ -481,14 +498,14 @@ class ConcreteCrackUseCase(BaseProcessor):
             ]
 
         tracking_stat=self.create_tracking_stats(total_counts=total_counts, current_counts=current_counts,
-                            detections=detections, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
-                            reset_settings=reset_settings, start_time=high_precision_start_timestamp ,
-                            reset_time=high_precision_reset_timestamp)
+                             detections=detections, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
+                             reset_settings=reset_settings, start_time=high_precision_start_timestamp ,
+                             reset_time=high_precision_reset_timestamp)
 
         tracking_stats.append(tracking_stat)
         return tracking_stats
 
-    def _generate_business_analytics(self, counting_summary: Dict, zone_analysis: Dict, config: ConcreteCrackConfig, stream_info: Optional[Dict[str, Any]] = None, is_empty=False) -> List[Dict]:
+    def _generate_business_analytics(self, counting_summary: Dict, alerts:Any, config: ConcreteCrackConfig, stream_info: Optional[Dict[str, Any]] = None, is_empty=False) -> List[Dict]:
         """Generate standardized business analytics for the agg_summary structure."""
         if is_empty:
             return []
@@ -571,6 +588,12 @@ class ConcreteCrackUseCase(BaseProcessor):
         Return total unique track_id count for each category.
         """
         return {cat: len(ids) for cat, ids in getattr(self, '_per_category_total_track_ids', {}).items()}
+    
+
+    def _format_timestamp_for_stream(self, timestamp: float) -> str:
+        """Format timestamp for streams (YYYY:MM:DD HH:MM:SS format)."""
+        dt = datetime.fromtimestamp(timestamp, tz=timezone.utc)
+        return dt.strftime('%Y:%m:%d %H:%M:%S')
 
     def _format_timestamp_for_video(self, timestamp: float) -> str:
         """Format timestamp for video chunks (HH:MM:SS.ms format)."""
@@ -579,11 +602,6 @@ class ConcreteCrackUseCase(BaseProcessor):
         seconds = round(float(timestamp % 60),2)
         return f"{hours:02d}:{minutes:02d}:{seconds:.1f}"
 
-    def _format_timestamp_for_stream(self, timestamp: float) -> str:
-        """Format timestamp for streams (YYYY:MM:DD HH:MM:SS format)."""
-        dt = datetime.fromtimestamp(timestamp, tz=timezone.utc)
-        return dt.strftime('%Y:%m:%d %H:%M:%S')
-
     def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False, frame_id: Optional[str]=None) -> str:
         """Get formatted current timestamp based on stream type."""
         if not stream_info:
@@ -659,6 +677,7 @@ class ConcreteCrackUseCase(BaseProcessor):
             dt = dt.replace(minute=0, second=0, microsecond=0)
             return dt.strftime('%Y:%m:%d %H:%M:%S')
 
+
     def _count_categories(self, detections: list, config: ConcreteCrackConfig) -> dict:
         """
         Count the number of detections per category and return a summary dict.
